@@ -3,14 +3,15 @@ package PPI::Util;
 # Provides some common utility functions that can be imported
 
 use strict;
-use UNIVERSAL 'isa';
 use base 'Exporter';
 use PPI::Document ();
+use Params::Util '_INSTANCE',
+                 '_SCALAR';
 
 use vars qw{$VERSION @EXPORT_OK};
 BEGIN {
-	$VERSION = '0.993';
-	@EXPORT_OK = qw{_Document};
+	$VERSION   = '0.995';
+	@EXPORT_OK = '_Document';
 }
 
 
@@ -20,14 +21,14 @@ BEGIN {
 #####################################################################
 # Functions
 
-# Allows a sub that takes a PPI::Document to handle the full range
+# Allows a sub that takes a L<PPI::Document> to handle the full range
 # of different things, including file names, SCALAR source, etc.
 sub _Document {
 	shift if @_ > 1;
 	return undef unless defined $_[0];
 	return PPI::Document->new( shift ) unless ref $_[0];
-	return PPI::Document->new( shift ) if ref $_[0] eq 'SCALAR';
-	return shift if isa($_[0], 'PPI::Document');
+	return PPI::Document->new( shift ) if _SCALAR($_[0]);
+	return shift if _INSTANCE($_[0], 'PPI::Document');
 	undef;
 }
 
